@@ -2,7 +2,7 @@
  *
  *  BlueZ - Bluetooth protocol stack for Linux
  *
- *  Copyright (C) 2004-2008  Marcel Holtmann <marcel@holtmann.org>
+ *  Copyright (C) 2004-2010  Marcel Holtmann <marcel@holtmann.org>
  *
  *
  *  This library is free software; you can redistribute it and/or
@@ -28,8 +28,11 @@
 #include <unistd.h>
 #include <pthread.h>
 
+#include "gstpragma.h"
 #include "gsta2dpsink.h"
 
+GType gst_avdtp_sink_get_type(void);
+
 GST_DEBUG_CATEGORY_STATIC(gst_a2dp_sink_debug);
 #define GST_CAT_DEFAULT gst_a2dp_sink_debug
 
@@ -79,7 +82,7 @@ static void gst_a2dp_sink_finalize(GObject *obj)
 
 	g_mutex_free(self->cb_mutex);
 
-	G_OBJECT_CLASS (parent_class)->finalize (obj);
+	G_OBJECT_CLASS(parent_class)->finalize(obj);
 }
 
 static GstState gst_a2dp_sink_get_state(GstA2dpSink *self)
@@ -97,8 +100,8 @@ static GstState gst_a2dp_sink_get_state(GstA2dpSink *self)
  * Helper function to create elements, add to the bin and link it
  * to another element.
  */
-static GstElement* gst_a2dp_sink_init_element(GstA2dpSink *self,
-			const gchar* elementname, const gchar* name,
+static GstElement *gst_a2dp_sink_init_element(GstA2dpSink *self,
+			const gchar *elementname, const gchar *name,
 			GstElement *link_to)
 {
 	GstElement *element;
@@ -141,8 +144,7 @@ remove_element_and_fail:
 	return NULL;
 
 cleanup_and_fail:
-	if (element != NULL)
-		g_object_unref(G_OBJECT(element));
+	g_object_unref(G_OBJECT(element));
 
 	return NULL;
 }
@@ -297,7 +299,7 @@ static GstStateChangeReturn gst_a2dp_sink_change_state(GstElement *element,
 		return ret;
 
 	ret = GST_ELEMENT_CLASS(parent_class)->change_state(element,
-                        transition);
+								transition);
 
 	switch (transition) {
 	case GST_STATE_CHANGE_PAUSED_TO_READY:
@@ -388,7 +390,7 @@ static GstCaps *gst_a2dp_sink_get_caps(GstPad *pad)
 		caps = gst_a2dp_sink_get_device_caps(self);
 		if (caps == NULL)
 			caps = gst_static_pad_template_get_caps(
-                                &gst_a2dp_sink_factory);
+					&gst_a2dp_sink_factory);
 	}
 	caps_aux = gst_caps_copy(caps);
 	g_object_set(self->capsfilter, "caps", caps_aux, NULL);
@@ -441,7 +443,7 @@ static gboolean gst_a2dp_sink_init_avdtp_sink(GstA2dpSink *self)
 	return TRUE;
 
 remove_element_and_fail:
-	gst_element_set_state (sink, GST_STATE_NULL);
+	gst_element_set_state(sink, GST_STATE_NULL);
 	gst_bin_remove(GST_BIN(self), sink);
 	return FALSE;
 
@@ -637,10 +639,10 @@ static gboolean gst_a2dp_sink_init_fakesink(GstA2dpSink *self)
 	if (self->fakesink != NULL)
 		return TRUE;
 
-	g_mutex_lock (self->cb_mutex);
+	g_mutex_lock(self->cb_mutex);
 	self->fakesink = gst_a2dp_sink_init_element(self, "fakesink",
 			"fakesink", self->capsfilter);
-	g_mutex_unlock (self->cb_mutex);
+	g_mutex_unlock(self->cb_mutex);
 
 	if (!self->fakesink)
 		return FALSE;
@@ -693,9 +695,9 @@ static void gst_a2dp_sink_init(GstA2dpSink *self,
 
 }
 
-gboolean gst_a2dp_sink_plugin_init (GstPlugin * plugin)
+gboolean gst_a2dp_sink_plugin_init(GstPlugin *plugin)
 {
-	return gst_element_register (plugin, "a2dpsink",
-			GST_RANK_PRIMARY, GST_TYPE_A2DP_SINK);
+	return gst_element_register(plugin, "a2dpsink",
+			GST_RANK_MARGINAL, GST_TYPE_A2DP_SINK);
 }
 
